@@ -218,7 +218,21 @@ int CTiles_Provider::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Param
 			(*pParameters)["EXTENT"].asInt() == 1 ? (*pParameters)["SHAPES"].asDataObject() :
 			(*pParameters)["EXTENT"].asInt() >= 2 ? (*pParameters)["GRID"  ].asDataObject() : NULL;
 
-		pParameters->Set_Enabled("CRS_PICKER", !SG_Get_Data_Manager().Exists(pObject) || !pObject->Get_Projection().is_Okay());
+		CSG_Projection Projection;
+		
+		if( SG_Get_Data_Manager().Exists(pObject) )
+		{
+			Projection.Create(pObject->Get_Projection());
+		};
+
+		pParameters->Set_Enabled("CRS_PICKER", !Projection.is_Okay());
+
+		if( !Projection.is_Okay() )
+		{
+			Projection.Create((*pParameters)("CRS_STRING")->asString());
+		}
+
+		pParameters->Set_Enabled("CELLSIZE", Projection.is_Projection());
 	}
 
 	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
@@ -300,7 +314,7 @@ bool CTiles_Provider::On_Execute(void)
 	}
 
 	//--------------------------------------------------------
-	if( !Projection.is_Geographic() )
+	if( Projection.is_Projection() )
 	{
 		if( Parameters("EXTENT")->asInt() != 3 ) // grid system
 		{
@@ -336,7 +350,7 @@ bool CTiles_Provider::On_Execute(void)
 	}
 
 	//--------------------------------------------------------
-	if( !Provide_Tiles(Directory, Extent_GCS, Parameters["DELARCHIVE"].asBool()) )
+	if( !Provide_Tiles(Directory, Extent_GCS, Parameters["DELARCHIVE"].asBool()) || !Process_Get_Okay() )
 	{
 		return( false );
 	}
@@ -368,7 +382,7 @@ bool CTiles_Provider::On_Execute(void)
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
 	//--------------------------------------------------------
-	if( Projection.is_Geographic() )
+	if( Projection.is_Geographic() || Projection.is_Geodetic() )
 	{
 		pGrid->Set_Name(m_Grid_Name);
 
@@ -554,17 +568,23 @@ bool CTiles_Provider::Update_VRT(const CSG_String &Directory)
 	//-----------------------------------------------------
 	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 12);
 
-	if( !pTool
-	||  !pTool->Set_Parameter("FILES"   , Tiles)
-	||  !pTool->Set_Parameter("VRT_NAME", SG_File_Make_Path(Directory, m_VRT_Name, "vrt"))
-	||  !pTool->Execute() )
+	SG_UI_ProgressAndMsg_Lock(true);
+
+	bool bResult = pTool
+		&& pTool->Set_Parameter("FILES"   , Tiles)
+		&& pTool->Set_Parameter("VRT_NAME", SG_File_Make_Path(Directory, m_VRT_Name, "vrt"))
+		&& pTool->Execute();
+
+	SG_UI_ProgressAndMsg_Lock(false);
+
+	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+
+	if( !bResult )
 	{
 		Error_Set(_TL("failed to update Virtual Raster Tiles file"));
-
-		return( false );
 	}
 
-	return( true );
+	return( bResult );
 }
 
 
